import { useVirtualList } from "ahooks";
import { Button, Col, Row, Image, Spin, Space, Drawer } from "antd";
import { JSXElementConstructor, Key, ReactElement, ReactFragment, ReactPortal, useEffect, useRef, useState } from "react";
import { ReactComponent as SuoSvg } from '@/assets/suo.svg';
function ReadBook(props: { next: (data: { id: number }) => Promise<any>, listData: any }) {
    let { next, listData } = props;
    const divRef = useRef<HTMLDivElement>(null);
    const [isFetching, setIsFetching] = useState(true);
    const [newData, setNewData] = useState<any>(null);
    const [content, setContent] = useState<any>(null)
    const list = useVirtualList(listData?.list || [],{
        containerTarget: undefined,
        wrapperTarget: undefined,
        itemHeight: 0
    });

    useEffect(() => {
        const handleKeyDown = (event: KeyboardEvent) => {
            if (divRef.current) {
                if (event.key === "ArrowDown") {
                    divRef.current.scrollBy(0, 50);
                } else if (event.key === "ArrowUp") {
                    divRef.current.scrollBy(0, -50);
                }
            }
        };
        window.addEventListener("keydown", handleKeyDown);
        return () => {
            window.removeEventListener("keydown", handleKeyDown);
        };
    }, []);


    async function getBookContent(id: any) {
        let content = await next(id)
        setContent(content)
    }
    useEffect(() => {
        if (divRef.current) {
            divRef.current.scrollTop = 0
        }
    }, [content, divRef])
    return (
        listData && <div
            style={{ height: '85vh', overflow: 'hidden', display: 'flex', justifyContent: 'space-around' }}
        >
            <div style={{ width: '20%', flexFlow: 'column', alignItems: 'center', display: 'flex', borderRight: '1px solid #efefef' }}>
                <Image src={listData?.picUrl} style={{ width: 150, marginBottom: 20 }} />
                <Row style={{ width: '80%' }}>
                    <Col span={24} style={{ fontSize: 14, color: "#777" }}><span style={{ color: "#333" }}><span>作者</span>：</span>{listData?.authorName}</Col>
                    <Col span={24} style={{ fontSize: 14, color: "#777" }}><span style={{ color: "#333" }}><span>来源</span>：</span>{({ "UPLOAD": "管理员", "CREATOR": "创作者" } as any)[listData.source]}</Col>
                    <Col span={24} style={{ fontSize: 14, color: "#777" }}><span style={{ color: "#333" }}><span>频道</span>：</span>{listData?.corpUserName == 0 ? "男频" : "女频"}</Col>
                    <Col span={24} style={{ fontSize: 14, color: "#777" }}><span style={{ color: "#333" }}>标签：</span> {
                        listData?.labels?.map((tags: { id: string, name: string }, index: number) => {
                            return tags?.name
                        }).join(',')
                    }</Col>
                    <Col span={24} style={{ fontSize: 14, color: "#777" }} ><span style={{ color: "#333" }}><span>状态</span>：</span>{["连载中", "已完结"][listData.bookStatus]}</Col>
                    <Col span={24} style={{ fontSize: 14, color: "#777" }}><span style={{ color: "#333" }}>评分：</span>{listData?.score || 0}</Col>
                    <Col span={24} style={{ fontSize: 14, color: "#777" }}><span style={{ color: "#333" }}>点击量：</span>{listData?.visitCount}</Col>
                    <Col span={24} style={{ fontSize: 14, color: "#777" }}><span style={{ color: "#333" }}>总字数：</span>{listData?.wordCount}</Col>
                    <Col span={24} style={{ fontSize: 14, color: "#777" }}><span style={{ color: "#333" }}>上架状态：</span>{["上架中", "已下架"][listData.shelveStatus]}</Col>
                    <Col span={24} style={{ fontSize: 14, color: "#777" }}><span style={{ color: "#333" }}>描述：</span>{listData.bookDesc}</Col>

                </Row>
            </div>
            <div
                style={{ overflowY: 'auto', display: 'flex', flexFlow: "column", width: '75%' }}
                ref={divRef}
            >
                <div >
                    {/* {list?.map((ele) => (
                        <a
                            key={ele.index}
                            style={{ display: 'inline-block', marginRight: ele.index % 4 === 0 ? 0 : 20, marginBottom: 10, width: 190, overflow: 'hidden' }}
                            onClick={() => { getBookContent(ele.data.chapterInfo.id) }}
                        >
                            <div style={{ display: 'flex', alignItems: 'center' }}>
                                {ele.data.needPay && <SuoSvg width={15} height={15} style={{ marginRight: 5 }} />}
                                <span >{ele.data.chapterInfo.chapterName}</span>
                            </div>
                        </a>
                    ))} */}
                </div>
                {/* 阅读小说 */}
                <Drawer
                    open={!!content}
                    placement="right"
                    onClose={() => { setContent(null) }}
                    footer={null}
                    width={'60%'}
                    destroyOnClose={true}
                    bodyStyle={{ padding: 0 }}
                    closeIcon={false}
                    title={<div style={{ fontSize: 20 }}>{content?.chapterName}</div>}
                >
                    {
                        content && <>
                            <div
                                ref={divRef}
                                style={{ borderTop: '1px solid #efefef', fontSize: 17,lineHeight:2, padding: '0 40px', height: '87vh', overflowY: 'auto', paddingBottom: 50,paddingTop:15, boxSizing: 'border-box' }} dangerouslySetInnerHTML={{ __html: content.content.replace(/\n/g, '<br/>') }}></div>
                            <div style={{ borderTop: '1px solid #efefef', display: 'flex', justifyContent: 'center' }}>
                                <Space style={{ marginTop: 15 }}>
                                    {content?.chapterNo > 1 && <Button onClick={() => {
                                        let upId = null
                                        for (let i = 0; i < listData?.list?.length; i++) {
                                            if (listData?.list[i].chapterInfo.id === content.id) {
                                                upId = listData?.list[i - 1].chapterInfo.id
                                                break;
                                            }
                                        }
                                        getBookContent(upId)
                                    }}>上一章</Button>}
                                    {content?.chapterNo < listData?.list?.length && <Button onClick={() => {
                                        let downId = null
                                        for (let i = 0; i < listData?.list?.length; i++) {
                                            if (listData?.list[i].chapterInfo.id === content.id) {
                                                downId = listData?.list[i + 1].chapterInfo.id
                                                break;
                                            }
                                        }
                                        getBookContent(downId)
                                    }}>下一章</Button>}
                                </Space>
                            </div>
                        </>
                    }
                </Drawer>

            </div>

        </div>
    );
}

export default ReadBook;
